From d9bdf09d49b481c369e95afeafa2039fc9a8ea4f Mon Sep 17 00:00:00 2001
From: Tim Daly <daly@axiom-developer.org>
Date: Mon, 19 Jan 2015 23:29:42 -0500
Subject: bug 7296: connect from VIEW2D is not graph specific

The connect function in VIEW2D globally turns lines on or off.
This doesn't allow for overlaying lines on a set of points.
---
 buglist                        |   38 +++++++++++++++++++++++++++++-
 changelog                      |    2 +
 patch                          |   51 ++-------------------------------------
 src/axiom-website/patches.html |    2 +
 4 files changed, 44 insertions(+), 49 deletions(-)

diff --git a/buglist b/buglist
index 599d3f1..c56edc1 100644
--- a/buglist
+++ b/buglist
@@ -1,6 +1,6 @@
 =========================================================================
 
-bug 7296: 
+bug 7297: 
 todo 337:
 wish 1012:
 meh 5:
@@ -12,6 +12,42 @@ dup 50006:
 nonextend 60077:
 
 =========================================================================
+bug 7296: connect from VIEW2D is not graph specific
+
+The connect function in VIEW2D globally turns lines on or off.
+This doesn't allow for overlaying lines on a set of points.
+
+)clear all
+FIN:=FiniteField(67,1)  -- declare a field p**n, p=67, n=1
+f(x:INT,y:INT):FIN == (y^2-x^3-7)::FIN -- compute a finite point
+m():LIST(POINT(DFLOAT)) ==
+  lli:LIST(LIST(INT)) := []
+  for x in 0..66 repeat
+   for y in 0..66 repeat
+    a:FIN:=f(x,y)
+    if a = 0 then lli:=concat(lli,[[x,y]])
+  ld:=lli::LIST(LIST(DFLOAT))
+  lpd:=[point(p) for p in ld]
+m()
+line(x1:INT,y1:INT,x2:INT,y2:INT):EXPR(INT) ==
+    -- y-y1 = m(x-x1) where m = (y2-y1)/x2-x1)
+  (y2-y1)/(x2-x1)*(x-x1) + y1
+line1:=draw(line(2,22,6,25),x=0..67)
+line1graph:=getGraph(line1,1)
+line2:=draw(line(30,26,47,39),x=0..67)
+line2graph:=getGraph(line2,1)
+ldo:=title("BitCoin Modular Points")
+vp:=draw(m(),[ldo])$DRAWPT
+putGraph(vp,line1graph,2)
+putGraph(vp,line2graph,3)
+axes(vp,1,"on")$VIEW2D -- turn on the axes
+units(vp,1,"on")$VIEW2D -- turn on the units
+connect(vp,2,"on")$VIEW2D -- turn on the lines
+connect(vp,3,"on")$VIEW2D -- turn on the lines
+connect(vp,1,"off")$VIEW2D -- turn off the lines
+makeViewport2D(vp)
+
+=========================================================================
 bug 7295: guessRat : (1 . arbitrary) cannot be coerced
 
 t1:=guessRat(q)([1,q,q^2], [])
diff --git a/changelog b/changelog
index 70822c5..932523d 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,5 @@
+20150118 tpd src/axiom-website/patches.html 20150119.01.tpd.patch
+20150119 tpd bug 7296: connect from VIEW2D is not graph specific
 20150118 tpd src/axiom-website/patches.html 20150118.01.tpd.patch
 20150118 tpd src/axiom-website/download.html add Docker instructions
 20150115 tpd src/axiom-website/patches.html 20150115.02.tpd.patch
diff --git a/patch b/patch
index 13d2979..9ab3a3a 100644
--- a/patch
+++ b/patch
@@ -1,49 +1,4 @@
-src/axiom-website/download.html add Docker instructions
-
-<h1>Axiom on Docker:</h1>
-You can run Axiom on any platform using Docker.
-
-<h3>Linux Docker</h3>
-<ol>
- <li> Remove the wrong "docker"
-  <ol>
-   <li> sudo apt-get remove -y docker
-  </ol>
- <li> install docker.io 
-  <ol>
-   <li> sudo apt-get install -y docker
-  </ol>
- <li> fetch Axiom in a Docker container
-  <ol>
-   <li> sudo docker pull daly/axiom
-  </ol>
- <li> run Axiom
-  <ol>
-   <li> sudo docker run -i -t daly/axiom axiom
-  </ol>
-</ol>
-
-Note that you can run docker in Linux using VirtualBox on any platform.
-
-<h3>Windows Docker</h3>
-Visit this 
-<a href="https://docs.docker.com/installation/windows">DOCKER </a>page
-which has instructions for installing docker. 
-
-Once the boot2docker window appears type
-<pre>
-  docker pull daly/axiom
-  docker run -i -t daly/axiom axiom
-</pre>
-
-<h3>Mac OS X Docker</h3>
-Visit this 
-<a href="https://docs.docker.com/installation/mac">DOCKER </a>page
-which has instructions for installing docker. 
-
-Once the boot2docker window appears type
-<pre>
-  docker pull daly/axiom
-  docker run -i -t daly/axiom axiom
-</pre>
+bug 7296: connect from VIEW2D is not graph specific
 
+The connect function in VIEW2D globally turns lines on or off.
+This doesn't allow for overlaying lines on a set of points.
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 485d6f2..a140fa2 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -4958,6 +4958,8 @@ src/input/intlinear4.input added to the unit test suite<br/>
 books/bookvol10 add SimpleCell to the algebra regression tests
 <a href="patches/20150118.01.tpd.patch">20150118.01.tpd.patch</a>
 src/axiom-website/download.html add Docker instructions<br/>
+<a href="patches/20150119.01.tpd.patch">20150119.01.tpd.patch</a>
+bug 7296: connect from VIEW2D is not graph specific<br/>
  </body>
 </html>
 
-- 
1.7.5.4

